@@ -1,3 +1,5 @@
+""" Async client to access the mattermost API """
+
 from collections.abc import AsyncGenerator
 from contextlib import asynccontextmanager
 from typing import Optional
@@ -60,6 +62,37 @@ from .exceptions import (
 )
 
 
+async def raise_on_4xx_5xx(response):
+    try:
+        response.raise_for_status()
+    except httpx.HTTPStatusError as http_error:
+        try:
+            await http_error.response.aread()
+            data = http_error.response.json()
+            message = data.get("message", data)
+        except ValueError:
+            message = response.text
+        if http_error.response.status_code == 400:
+            raise InvalidOrMissingParameters(message) from http_error
+        if http_error.response.status_code == 401:
+            raise NoAccessTokenProvided(message) from http_error
+        if http_error.response.status_code == 403:
+            raise NotEnoughPermissions(message) from http_error
+        if http_error.response.status_code == 404:
+            raise ResourceNotFound(message) from http_error
+        if http_error.response.status_code == 405:
+            raise MethodNotAllowed(message) from http_error
+        if http_error.response.status_code == 413:
+            raise ContentTooLarge(message) from http_error
+        if http_error.response.status_code == 429:
+            raise TooManyRequests(message) from http_error
+        if http_error.response.status_code == 500:
+            raise InternalServerError(message) from http_error
+        if http_error.response.status_code == 501:
+            raise FeatureDisabled(message) from http_error
+        raise
+
+
 class AsyncClient(BaseClient):
     """Synchronous mattermost api client implementation"""
 
@@ -78,13 +111,13 @@ class AsyncClient(BaseClient):
             base_url=base_url, **dict(httpx_client_options)
         )
         httpx_client.event_hooks["response"] = [
-            self.raise_on_4xx_5xx
+            raise_on_4xx_5xx
         ] + httpx_client.event_hooks["response"]
         if isinstance(self.options.auth, AuthToken):
             httpx_client.auth = self.options.auth
             self.active_token = self.options.auth.token
         if isinstance(self.options.auth, AuthLogin):
-            """Login with username and password and get a session_token"""
+            # Login with username and password and get a session_token
             response = await httpx_client.post(
                 url="/users/login", json=self.options.auth.dict(exclude_unset=True)
             )
@@ -93,36 +126,6 @@ class AsyncClient(BaseClient):
             self.active_token = session_token
         return httpx_client
 
-    async def raise_on_4xx_5xx(self, response):
-        try:
-            response.raise_for_status()
-        except httpx.HTTPStatusError as e:
-            try:
-                await e.response.aread()
-                data = e.response.json()
-                message = data.get("message", data)
-            except ValueError:
-                message = response.text
-            if e.response.status_code == 400:
-                raise InvalidOrMissingParameters(message) from e
-            if e.response.status_code == 401:
-                raise NoAccessTokenProvided(message) from e
-            if e.response.status_code == 403:
-                raise NotEnoughPermissions(message) from e
-            if e.response.status_code == 404:
-                raise ResourceNotFound(message) from e
-            if e.response.status_code == 405:
-                raise MethodNotAllowed(message) from e
-            if e.response.status_code == 413:
-                raise ContentTooLarge(message) from e
-            if e.response.status_code == 429:
-                raise TooManyRequests(message) from e
-            if e.response.status_code == 500:
-                raise InternalServerError(message) from e
-            if e.response.status_code == 501:
-                raise FeatureDisabled(message) from e
-            raise
-
     async def _login(self):
         """Calling this creates a httpx client and sets .active_token, needed for websockets"""
         await self._create_httpx_client()
@@ -142,6 +145,7 @@ class AsyncClient(BaseClient):
     @asynccontextmanager
     async def session(self) -> AsyncGenerator["AsyncClient", None, None]:
         """Open a Session which re-uses the underlying httpx client and it's connections"""
+        # pylint: disable=protected-access
         api_client = self.copy()
         api_client._httpx_client = await api_client._create_httpx_client()
         try:
